@@ -15,7 +15,7 @@ smsn.mmix <- function(y, nu=1, mu = NULL, Sigma = NULL, shape = NULL, pii = NULL
   if((length(g) == 0) && ((length(mu)==0) || (length(Sigma)==0) || (length(shape)==0) || (length(pii)==0)))  stop("The model is not specified correctly.\n")
   if(get.init == FALSE){
        g <- length(mu)
-       if((length(mu) != ncol(y)) || (length(mu) != length(Sigma)) || (length(mu) != length(shape)) || (length(mu) != length(pii))) stop("The size of the initial values are not compatibles.\n")
+       if((length(mu) != g) || (length(mu) != length(Sigma)) || (length(mu) != length(shape)) || (length(mu) != length(pii))) stop("The size of the initial values are not compatibles.\n")
 
        if(sum(pii) != 1) stop("probability of pii does not sum to 1.\n")
        for (j in 1:g){
